this.PaymentProviderMock = (function (global) {
    "use strict";
    return {
        initialize: function (initParams, callback) {
            var container = global.document.getElementById("mock_payment");
            if (!container) {
                return {
                    success: false,
                    error: "The mock payment container does not exist.",
                };
            }

            container.innerHTML = "<div id='form_title'>" + initParams.formTitle + "</div>";
            var respondWithSuccess = function () {
                container.innerHTML = "";
                callback({
                    success: "true",
                });
            };
            var successButton = global.document.createElement("button");
            successButton.setAttribute("id", "button_success");
            successButton.textContent = "SUCCESS";
            if (successButton.addEventListener) {
                successButton.addEventListener("click", respondWithSuccess, false);
            } else {
                successButton.attachEvent("click", respondWithSuccess);
            }

            container.appendChild(successButton);

            var respondWithError = function () {
                callback({
                    success: "false",
                    error: "error",
                    /* eslint-disable camelcase */
                    error_description: "error description",
                    /* eslint-enable camelcase */
                });
            };
            var errorButton = global.document.createElement("button");
            errorButton.setAttribute("id", "button_error");
            errorButton.textContent = "ERROR";
            if (errorButton.addEventListener) {
                errorButton.addEventListener("click", respondWithError, false);
            } else {
                errorButton.attachEvent("click", respondWithError);
            }

            container.appendChild(errorButton);

            // when autoSubmitDelayMS and autoSubmitResult are both defined, this mock
            // page is turned into auto submit form for automated test
            if (initParams !== undefined && initParams.autoSubmitDelayMS !== undefined && initParams.autoSubmitResult !== undefined) {
                var buttonId = (initParams.autoSubmitResult === true) ? "button_success" : "button_error";
                global.window.setTimeout(function () {
                    var button = global.document.getElementById(buttonId);
                    if (button) {
                        button.click();
                    }
                }, initParams.autoSubmitDelayMS);
            }

            return {
                success: true,
            };
        },
        showError: function (__field, __message) {
            // no-op for mock provider
        },
    };
})(this);
