#version 310 es

precision mediump float;

uniform sampler2D u_Thumbnail;
uniform vec4 u_BorderColor;
uniform vec2 u_BorderWidthShift;
uniform vec2 u_BorderIntensityMultiply;
uniform float u_alpha;
uniform vec2 u_SampleAspect;
uniform vec2 u_SampleOrigin;

in vec2 v_TexCoordinate;

out vec4 fragColor;

void main()
{
    vec2 sampleCoordinate = (v_TexCoordinate * u_SampleAspect) + u_SampleOrigin;
    vec4 color = texture(u_Thumbnail, sampleCoordinate);

    // Adjust u and v to be in the range of -1 to 1...then abs to 0-1 (so left and right, top and bottom
    // are at 1, center at 0).
    vec2 borderPosition = clamp(abs((v_TexCoordinate - 0.5f) * 2.0f), 0.0f, 1.0f);

    // Now adjust the normalized scale so anything in the border region is > 1.0...
    borderPosition *= u_BorderWidthShift;

    float borderIntensity = sqrt(max(clamp((borderPosition.x - 1.0f) * u_BorderIntensityMultiply.x, 0.0f, 1.0f),
                                     clamp((borderPosition.y - 1.0f) * u_BorderIntensityMultiply.y, 0.0f, 1.0f)));

    vec4 mixedColor = mix(color, u_BorderColor, borderIntensity);
    mixedColor.a = min(u_alpha, mixedColor.a);
    fragColor = mixedColor;
}

